import java.awt.*;
import java.awt.image.*;
import java.io.*;
import java.util.*;
import javax.imageio.*;


public class Transformations {
    private int[][] myPixels;

    /**
     * Constructor takes in the file that contains the image
     * and converts it to a BufferedImage. This image is stored
     * in an instance variable in the form of an integer array.
     *
     *         DO NOT MODIFY THIS METHOD
     *
     * @param file, file that contains the image
     */
    public Transformations(File file) {
        BufferedImage img;
        try {
            img = ImageIO.read(file);
        } catch (Exception e) {
            System.out.println("Incorrect File ");
            return;
        }
        if (img.getType() == BufferedImage.TYPE_INT_RGB) {
            myPixels = imageToPixels(img);
        } else {
            BufferedImage tmpImage = new BufferedImage(img.getWidth(null), img.getHeight(null), BufferedImage.TYPE_INT_RGB);
            tmpImage.createGraphics().drawImage(img, 0, 0, null);
            myPixels = imageToPixels(tmpImage);
        }
    }

    /**
     * Method to return the original image
     *
     *         DO NOT MODIFY THIS METHOD
     *
     * @return image, the original image
     */
    public int[][] getPixels() {
        return myPixels;
    }


	/**
	 * Method to adjust the brightness of the image. In order to adjust the brightness
	 * by a value val, either by increasing or decreasing it, you should make sure
	 * increase or decrease all the channels (colors) of the RGB model by val.
	 * In case some color exceeds its maximum allowed value (255) or
	 * goes below its minimum allowed value (0), make sure to set it to the max
	 * or min possible allowed value.
	 *
	 * @param val, the value by which you should adjust the brightness
	 * @return image, the changed image
	 *
	*/
    public int[][] adjustBrightness(int val) {
		//insert your code here
		return null;
	}


	/**
	 * Method to mosaic the image. Each mosaic is a square where each
	 * edge length is the value of the parameter gridSize. Create a
	 * new array iPixels of the same size as myPixels. For each pixel
	 * at (x,y) in iPixels in one mosaic, copy the middle pixel in
	 * that mosaic in myPixels to (x,y), or put the average color of
	 * pixels in the mosaic in myPixels to (x,y).
	 *
	 * @param gridSize integer number that specifies the size of each mosaic
	 *
	 * @return image, the mosaic image
	 */
	public int[][] mosaic(int gridSize) {
		//insert your code here
		return null;
	}
	/**
	 * Method to rotate left the image
	 * @return image, the rotated image
	 */
	public int[][] rotateLeft() {
		//insert your code here
		return null;
	}


	//
    // add methods for the other effects here
    //



    /**
     * Converts a two-dimensional array of image data to a BufferedImage.
     *
     *         DO NOT MODIFY THIS METHOD
     *
     * @param pixels	the source two-dimensional array of image data
     *
     * @return	a BufferedImage representing the source image.
     *
     * @throws	IllegalArgumentException if the source image is
     *       	ill-defined.
     */
    public static BufferedImage pixelsToImage(int[][] pixels) throws IllegalArgumentException {
        if (pixels == null) {
            throw new IllegalArgumentException();
        }

        int width = pixels[0].length;
        int height = pixels.length;
        BufferedImage image = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
        for (int row = 0; row < height; row++) {
            image.setRGB(0, row, width, 1, pixels[row], 0, width);
        }
        return image;
    }

    /**
     * Converts a BufferedImage to a two-dimensional array of image data.
     *
     *         DO NOT MODIFY THIS METHOD
     *
     * @param image	the source BufferedImage
     *
     * @return	a two-dimensional array of image data representing the
     *        	source image
     *
     * @throws	IllegalArgumentException if the source image is
     *       	ill-defined.
     */
    public static int[][] imageToPixels(BufferedImage image) throws IllegalArgumentException {
        if (image == null) {
            throw new IllegalArgumentException();
        }

        int width = image.getWidth();
        int height = image.getHeight();
        int[][] pixels = new int[height][width];
        for (int row = 0; row < height; row++) {
            image.getRGB(0, row, width, 1, pixels[row], 0, width);
        }
        return pixels;
    }


    public static void main(String[] args) {
        Transformations tr = new Transformations(new File("image.jpg"));
        DrawingBox box = new DrawingBox();

        // display the original image
        BufferedImage originalImage = pixelsToImage(tr.getPixels());
        box.drawImage(originalImage, 0, 0);

        // mosaic the image and display it
        BufferedImage mosaicImage = pixelsToImage(tr.mosaic(5));
        box.drawImage(mosaicImage, 400, 0);

        // adjust the brightness of the image and display it
        BufferedImage bright1Image = pixelsToImage(tr.adjustBrightness(32));
        box.drawImage(bright1Image, 0, 400);

        // rotate left the image and display it
        BufferedImage rotateLeftImage = pixelsToImage(tr.rotateLeft());
        box.drawImage(rotateLeftImage, 400, 400);

        // add other transformations to the image
        // display at different (x, y) co-ordinates


    }
}
